backup_page — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

# backup_page

class `camelot.view.wizard.pages.backup_page.` `Page`(backup_mechanism=None, parent=None)

  Abstract class for the select file page of a backup and a restore file.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

Comments
blog comments powered by Disqus